//	GeometryGamesExportView.swift
//
//	© 2023 by Jeff Weeks
//	See TermsOfUse.txt

import SwiftUI
//import UniformTypeIdentifiers		See comment accompanying .fileExporter


struct GeometryGamesExportView<ModelDataType>: View {

	enum ExportedImageSize: Int, CaseIterable, Identifiable {

//	The 64, 128 and 192 pt image sizes are useful
//	for creating KaleidoPaint's symmetry group button images,
//	but aren't part of the publicly released KaleidoPaint.
//
//case size64   =  64
//case size128  =  128
//case size192  =  192

//#warning("Comment out these cases, which are needed only for making app icons.")
//#error("These are no longer needed.  iOS will automatically rescale the 1024×1024 icon to get whatever other sizes it needs.")
//case size76  =  76
//case size120 = 120
//case size152 = 152
//case size167 = 167
//case size180 = 180

//#warning("Comment out these cases, which are needed only for making app icons for the Geometry Games web site.")
//case size16 = 16
//case size128 = 128

//	Recall that KaleidoPaint's graphics code won't run
//	in the Simulator, even though it runs fine
//	as a standalone app on macOS.
//	The following indices are useful for specifying
//	the non-square image sizes needed to synthesize
//	KaleidoPaint's screenshots.
//
//#warning("also need to enable 'makeKaleidoPaintScreenshotImages' below for this to work")
//#warning("comment out these cases")
//case size1242x2076 = 0
//case size1290x2503 = 1
//case size2048x2632 = 2

		case size256  =  256
		case size512  =  512
		case size1024 = 1024
		case size2048 = 2048
		case size4096 = 4096
		
		var id: Int { self.rawValue }

		var asString: String {
		
			return "\(self.rawValue) × \(self.rawValue)"
		}
	}

	@State private var imageSizeInPixels = ExportedImageSize.size256	//	to be overridden in onAppear below
	@State private var exportWithTransparentBackground: Bool = false
//	See comment accompanying .fileExporter
//	@State private var isShowingFileExporter: Bool = false
	@StateObject var itsExporter = GeometryGamesDocumentExporter<ModelDataType>()
	let theDefaultExportedImageSize = ExportedImageSize.size1024
	let itsModelData: ModelDataType
	let itsExportRenderer: GeometryGamesRenderer<ModelDataType>
	let itsFolderName: String?
		//	KaleidoPaint and 4D Draw pass the current drawing's filename
		//	so that we may save exported images into a subfolder whose name
		//	matches the drawing's name (but of course without the filename extension).
	let itsImageName: String?
	let itsSpecialSaveTitle: LocalizedStringKey?	//	Used only by KaleidoPaint, for Save (Tileable) Rectangle

	init(
		modelData: ModelDataType,
		exportRenderer: GeometryGamesRenderer<ModelDataType>,
		folderName: String? = nil,	//	See comment accompanying itsFolderName above.
		imageName: String? = nil,	//	Optional default filename
		specialSaveTitle: LocalizedStringKey? = nil	//	Used only by KaleidoPaint,
													//	for Save (Tileable) Rectangle
	) {
		itsModelData = modelData
		itsExportRenderer = exportRenderer
		itsFolderName = folderName
		itsImageName = imageName
		itsSpecialSaveTitle = specialSaveTitle
	}
	
	var body: some View {
	
		let theButtonPadding: CGFloat = 4
		
		let theTitleString = Bundle.main.localizedString(
			forKey: "Export",
			value: nil,
			table: "GeometryGamesLocalizable")
		
		let theImageSizeString = Bundle.main.localizedString(
			forKey: "Image size",
			value: nil,
			table: "GeometryGamesLocalizable")
		
		let theTransparentBackgroundString = Bundle.main.localizedString(
			forKey: "Transparent background",
			value: nil,
			table: "GeometryGamesLocalizable")

		let theSaveImageString = Bundle.main.localizedString(
			forKey: "Save Image",
			value: nil,
			table: "GeometryGamesLocalizable")

		let theCopyImageString = Bundle.main.localizedString(
			forKey: "Copy Image",
			value: nil,
			table: "GeometryGamesLocalizable")
		
		return VStack(alignment: .center) {
			
			Text(theTitleString)
				.font(.title3)
			
			HStack() {
			
				Text(theImageSizeString)

				Spacer()

				Picker(
					theImageSizeString,
					selection: $imageSizeInPixels
				) {
					ForEach(ExportedImageSize.allCases, id: \.id) {theImageSize in
						Text(verbatim: theImageSize.asString)
							.tag(theImageSize)
					}
				}
				.pickerStyle(MenuPickerStyle())
			}
			
			Toggle(
				theTransparentBackgroundString,
				isOn: $exportWithTransparentBackground
			)
			.toggleStyle(.geometryGamesTransparencyCheckbox)
			
			//	Caution:  Divider() will make the HStack fill all available width
			//	unless we apply .fixedSize() or .fixedSize(horizontal: vertical: )
			//	to the containing VStack().
			Divider()
		
			Button() {

//	See comment accompanying .fileExporter
//				if let theFolderName = itsFolderName {

					//	If I can someday run KaleidoPaint in the Simulator,
					//	the following makeKaleidoPaintScreenshotImages code
					//	may be eliminated, along with the corresponding cases
					//	in the ExportedImageSize enum.
//#warning("disable makeKaleidoPaintScreenshotImages, and comment out the whole if-block")
//					let makeKaleidoPaintScreenshotImages = false
//
//					if makeKaleidoPaintScreenshotImages {
//
//						let theImageWidth: Int
//						let theImageHeight: Int
//						switch imageSizeInPixels.rawValue {
//
//							//	Enable gMeasureDrawingArea to get theImageHeight.
//
//							case 0:
//								theImageWidth  = 1242
//								theImageHeight = 2076	//	with status bar suppressed
//
//							case 1:
//								theImageWidth  = 1290
//								theImageHeight = 2503	//	with status bar suppressed
//
//							case 2:
//								theImageWidth  = 2048
//								theImageHeight = 2632	//	with status bar suppressed
//
//							default:
//								theImageWidth  = 32
//								theImageHeight = 32
//						}
//
//						let (_, _) = itsExporter.saveImage(
//							modelData: itsModelData,
//							renderer: itsExportRenderer,
//							requestedWidthPx:  theImageWidth,
//							requestedHeightPx: theImageHeight,
//							transparentBackground: exportWithTransparentBackground,
//							folderName: itsFolderName,
//							imageName: itsImageName)
//
//					} else {	//	normal saved images
					
						let (_, _) = itsExporter.saveImage(
							modelData: itsModelData,
							renderer: itsExportRenderer,
							requestedWidthPx:  imageSizeInPixels.rawValue,
							requestedHeightPx: imageSizeInPixels.rawValue,
							transparentBackground: exportWithTransparentBackground,
							folderName: itsFolderName,
							imageName: itsImageName)
//					}
						
//				} else {
//
//					isShowingFileExporter = true
//				}
					
			} label: {
				HStack() {
					Text(theSaveImageString)
					Spacer()
					Image(systemName: "folder")
				}
				.padding(EdgeInsets(top: theButtonPadding, leading: 0, bottom: theButtonPadding, trailing: 0))
			}
//	UIDocumentPickerViewController provides an option to save the image "asCopy".
//	The Save panel's confirmation button says "Save" when saving asCopy,
//	but says "Move" otherwise, which is not so intuitive for the end user.
//	Alas the SwiftUI fileExporter provides no "asCopy" option,
//	and always says "Move".  Ugh.  See
//		https://www.hackingwithswift.com/forums/swiftui/how-can-i-persuade-fileexporter-to-show-save-instead-of-move/14816
//
//	Another problem is how to specify the default directory.
//	The fileExporter always defaults to the top level, with a choice of
//
//		iCloud Drive
//		On My iPad
//
//	(A call to the FileManager's changeCurrentDirectoryPath() has no effect.)
//
//			.fileExporter(
//				isPresented: $isShowingFileExporter,
//				document: GeometryGamesImageDocument(),
//				contentType: .plainText
//			) { result in
//			}

			Button {
			
				let (_, _) = itsExporter.copyImage(
					modelData: itsModelData,
					renderer: itsExportRenderer,
					requestedWidthPx:  imageSizeInPixels.rawValue,
					requestedHeightPx: imageSizeInPixels.rawValue,
					transparentBackground: exportWithTransparentBackground)
					
			} label: {
			
				HStack() {
					Text(theCopyImageString)
					Spacer()
					Image(systemName: "doc.on.doc")
				}
				.padding(EdgeInsets(top: theButtonPadding, leading: 0, bottom: theButtonPadding, trailing: 0))
			}
			
			if let theSpecialSaveTitle = itsSpecialSaveTitle {
			
				Button() {
					let (_, _) = itsExporter.saveImage(
						modelData: itsModelData,
						renderer: itsExportRenderer,
						requestedWidthPx:  imageSizeInPixels.rawValue,
						requestedHeightPx: imageSizeInPixels.rawValue,
						transparentBackground: exportWithTransparentBackground,
						folderName: itsFolderName,
						imageName: itsImageName,
						isSpecialSave: true)
				} label: {
					HStack() {
						Text(theSpecialSaveTitle)
						Spacer()
						Image(systemName: "rectangle.split.3x3")	//	Currently used only by KaleidoPaint.
																	//	Image could be app-specific if necessary.
					}
					.padding(EdgeInsets(top: theButtonPadding, leading: 0, bottom: theButtonPadding, trailing: 0))
				}
			}
		}
		.frame(width: 300)
		.onAppear() {
			imageSizeInPixels = ExportedImageSize(rawValue:
				UserDefaults.standard.object(forKey: "exported image size")
					as? Int ?? theDefaultExportedImageSize.rawValue
			) ?? theDefaultExportedImageSize
		}
		.onDisappear() {
			UserDefaults.standard.setValue(
				imageSizeInPixels.rawValue,
				forKey: "exported image size")
		}
		.padding(geometryGamesPanelPadding)
		.background(Color(UIColor.systemBackground))
		.cornerRadius(geometryGamesCornerRadius)
	}
	
	func formattedImageSize(_ size: Int) -> String {
		
		let theNumberFormatter = NumberFormatter()
		theNumberFormatter.groupingSeparator = ""	//	suppress the comma in "1,024" etc.

		let theFormattedNumber = (theNumberFormatter.string(from: NSNumber(value: size))
									?? "error")
		
		let theDimensions = theFormattedNumber + " × " + theFormattedNumber
		
		return theDimensions
	}
}


class GeometryGamesDocumentExporter<ModelDataType>: NSObject, UIDocumentPickerDelegate, ObservableObject {
	//	To conform to UIDocumentPickerDelegate, we must also inherit from NSObject.
	
	private var itsTemporaryImageURL: URL?
	
	func copyImage(
		modelData: ModelDataType,
		renderer: GeometryGamesRenderer<ModelDataType>,
		requestedWidthPx: Int,
		requestedHeightPx: Int,
		transparentBackground: Bool
	) -> (Int, Int) {	//	returns rendered size

		let (theOptionalPngRepresentation, theRenderedWidthPx, theRenderedHeightPx)
			= renderer.offscreenImageAsPNG(
				modelData: modelData,
				extra: nil,	//	could provide subclass-specific value if desired
				requestedWidthPx: requestedWidthPx,
				requestedHeightPx: requestedHeightPx,
				transparentBackground: transparentBackground)

		guard let thePngRepresentation = theOptionalPngRepresentation else {
			return (0, 0)
		}

		UIPasteboard.general.setData(thePngRepresentation, forPasteboardType: "public.png")

		return (theRenderedWidthPx, theRenderedHeightPx)
	}

	func saveImage(
		modelData: ModelDataType,
		renderer: GeometryGamesRenderer<ModelDataType>,
		requestedWidthPx: Int,
		requestedHeightPx: Int,
		transparentBackground: Bool,
		folderName: String?,
		imageName: String?,
		isSpecialSave: Bool = false	//	KaleidoPaint uses isSpecialSave
									//	to implement Save Tileable Rectangle
	) -> (Int, Int) {	//	returns rendered size

		let (theOptionalPngRepresentation, theRenderedWidthPx, theRenderedHeightPx)
			= renderer.offscreenImageAsPNG(
				modelData: modelData,
				extra: nil,	//	could provide subclass-specific value if desired
				requestedWidthPx: requestedWidthPx,
				requestedHeightPx: requestedHeightPx,
				transparentBackground: transparentBackground,
				isSpecialSave: isSpecialSave)

		guard let thePngRepresentation = theOptionalPngRepresentation else {
			return (0, 0)
		}

		let theTemporaryImageURL = temporaryImageURL(imageName: imageName)
		
		//	Remember itsTemporaryImageURL so we can delete
		//	the temporary file when we're done.
		itsTemporaryImageURL = theTemporaryImageURL

		//	Note:  The following code uses UIKit.
		//	See comment accompanying .fileExporter().

		do {
			try thePngRepresentation.write(to: theTemporaryImageURL)

			//	In principle we'd be happy to let
			//	iOS move the temporary file,
			//	with no need to make a copy of it.
			//	The downside of that approach, though,
			//	is that the Document Picker would invite
			//	the user to "Move" the exported image.
			//	We'd much prefer that the Document Picker
			//	invite the user to "Save" the exported image,
			//	and for that to happen we need to ask it
			//	to save a copy of the temporary file.
			let theDocumentPickerViewController = UIDocumentPickerViewController(
													forExporting: [theTemporaryImageURL],
													asCopy: true)

			//	In principle we could ignore the temporary file,
			//	and iOS would eventually delete it (because it's
			//	in the temporaryDirectory).  But a cleaner solution
			//	is to make ourselves theDocumentPickerViewController's delegate
			//	and let the delegate callback methods delete
			//	the temporary file immediately.
			theDocumentPickerViewController.delegate = self

			//	If the caller asked that we start the user
			//	in a given default directory, create that directory (if needed)
			//	and pass its URL to theDocumentPickerViewController.
			//	The user is, of course, free to navigate
			//	to some other directory if s/he wishes.
			if let theFolderName = folderName {

				let theFileManager = FileManager.default

				let theExportFolderName = Bundle.main.localizedString(
										forKey: "Exported images",
										value: nil,
										table: "GeometryGamesLocalizable")
				
				//	The leading " " lets the "Exported images" folder appear first,
				//	assuming the user's drawings have typical alphanumeric names.
				//
				let theSubfolderPath = " " + theExportFolderName + "/" + theFolderName

				let theDocumentsDirectory = try theFileManager.url(
						for: .documentDirectory,
						in: .userDomainMask,
						appropriateFor: nil,
						create: true)

				let theSubfolderURL
					= theDocumentsDirectory.appendingPathComponent(theSubfolderPath)

				try theFileManager.createDirectory(	//	It's OK if the directory already exists.
					at: theSubfolderURL,
					withIntermediateDirectories: true,
					attributes: nil)

				theDocumentPickerViewController.directoryURL = theSubfolderURL
			}

			//	Locate top UIViewController on the stack,
			//	and ask it to present theDocumentPickerViewController.
			//
			//		Technical flaw
			//
			//			I would have much rather passed a reference
			//			to the GeometryGamesExportView into this
			//			GeometryGamesDocumentExporter, and used it
			//			to get a reference to its underlying UIViewController.
			//			But I can't figure out how to get from a SwiftUI View
			//			to a UIView or UIViewController.  So as a workaround,
			//			the code below fishes up an arbitrary window and uses it
			//			instead, which works in practice, even though it's
			//			a horrible "code smell".
			//
			//			Maybe in the future SwiftUI will drop its dependence
			//			on UIKit, and there'll be some cleaner way to present
			//			a purely SwiftUI DocumentPicker (keeping in mind that
			//			we're not creating a document-based app, we're just
			//			exporting an image from a non-document-based app).
			//
			if let theWindowScene = UIApplication.shared.connectedScenes.first as? UIWindowScene {
				if let theRootViewController = theWindowScene.windows.first?.rootViewController {

					var theTopViewController = theRootViewController
					while let thePresentedController = theTopViewController.presentedViewController {
						theTopViewController = thePresentedController
					}
		
					theTopViewController.present(theDocumentPickerViewController, animated: false)
				}
			}
			
		} catch {
			assertionFailure("Error saving image file")
		}

		return (theRenderedWidthPx, theRenderedHeightPx)
	}

	func documentPicker(_ controller: UIDocumentPickerViewController, didPickDocumentsAt urls: [URL]) {
		deleteTemporaryFile()
	}

	func documentPickerWasCancelled(_ controller: UIDocumentPickerViewController) {
		deleteTemporaryFile()
	}

	func deleteTemporaryFile() {

		if let theTemporaryImageURL = itsTemporaryImageURL {
		
			itsTemporaryImageURL = nil
			
			do {
				try FileManager.default.removeItem(at: theTemporaryImageURL)
			} catch {
				assertionFailure("Error deleting temporary image file")
			}
		}
	}

	func temporaryImageURL(
		imageName: String?
	) -> URL {

		let theTemporaryImageName: String
		if let theImageName = imageName {
		
			theTemporaryImageName = theImageName
			
		} else {
		
			theTemporaryImageName = Bundle.main.localizedString(
										forKey: "Untitled",
										value: nil,
										table: "GeometryGamesLocalizable"
									)
		}
		
		let theTemporaryImageURL = FileManager.default
									.temporaryDirectory
									.appendingPathComponent(
										theTemporaryImageName.appending(".png"))

		return theTemporaryImageURL
	}
}

//	See comment accompanying .fileExporter
//
//struct GeometryGamesImageDocument: FileDocument {
//
//	static var readableContentTypes: [UTType] { [.plainText] }
//
//	init() {
//	}
//
//	init(configuration: ReadConfiguration) throws {
//	}
//
//	func fileWrapper(configuration: WriteConfiguration) throws -> FileWrapper {
//		return FileWrapper(regularFileWithContents: "It works!".data(using: .utf8)! )
//	}
//}

struct GeometryGamesTransparencyCheckboxToggleStyle: ToggleStyle {

	func makeBody(configuration: Configuration) -> some View {

		HStack() {

			configuration.label
			//	.multilineTextAlignment(.leading)
			
			Spacer()
			
			Button() {
			
				configuration.isOn.toggle()
				
			} label: {
			
					Image(systemName:
						configuration.isOn ? "checkmark.square" : "square")
			}
			.buttonStyle(.borderless)
		}
	}
}

extension ToggleStyle where Self == GeometryGamesTransparencyCheckboxToggleStyle {
	static var geometryGamesTransparencyCheckbox: GeometryGamesTransparencyCheckboxToggleStyle { .init() }
}
